@@ -2,6 +2,8 @@ import sys
 import typing
 import bpy_types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
     bl_idname = None
@@ -19,9 +21,6 @@ class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -34,6 +33,18 @@ class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -64,6 +75,12 @@ class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -118,6 +135,18 @@ class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -153,9 +182,6 @@ class CLIP_OT_constraint_to_fcurve(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -168,6 +194,18 @@ class CLIP_OT_constraint_to_fcurve(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -198,6 +236,12 @@ class CLIP_OT_constraint_to_fcurve(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -246,6 +290,18 @@ class CLIP_OT_constraint_to_fcurve(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -281,9 +337,6 @@ class CLIP_OT_delete_proxy(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -296,6 +349,18 @@ class CLIP_OT_delete_proxy(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -332,6 +397,12 @@ class CLIP_OT_delete_proxy(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -386,6 +457,18 @@ class CLIP_OT_delete_proxy(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -421,12 +504,6 @@ class CLIP_OT_filter_tracks(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
-    track_threshold = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -439,6 +516,18 @@ class CLIP_OT_filter_tracks(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -469,6 +558,12 @@ class CLIP_OT_filter_tracks(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -523,6 +618,18 @@ class CLIP_OT_filter_tracks(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -555,9 +662,6 @@ class CLIP_OT_set_active_clip(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -570,6 +674,18 @@ class CLIP_OT_set_active_clip(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -600,6 +716,12 @@ class CLIP_OT_set_active_clip(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -654,6 +776,18 @@ class CLIP_OT_set_active_clip(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -689,9 +823,6 @@ class CLIP_OT_set_viewport_background(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -704,6 +835,18 @@ class CLIP_OT_set_viewport_background(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -734,6 +877,12 @@ class CLIP_OT_set_viewport_background(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -788,6 +937,18 @@ class CLIP_OT_set_viewport_background(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -823,9 +984,6 @@ class CLIP_OT_setup_tracking_scene(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -838,6 +996,24 @@ class CLIP_OT_setup_tracking_scene(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def createCollection(self, context, collection_name):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -868,6 +1044,12 @@ class CLIP_OT_setup_tracking_scene(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -922,6 +1104,18 @@ class CLIP_OT_setup_tracking_scene(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -957,9 +1151,6 @@ class CLIP_OT_track_settings_as_default(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -972,6 +1163,18 @@ class CLIP_OT_track_settings_as_default(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1002,6 +1205,12 @@ class CLIP_OT_track_settings_as_default(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1056,6 +1265,18 @@ class CLIP_OT_track_settings_as_default(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1091,9 +1312,6 @@ class CLIP_OT_track_settings_to_track(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -1106,6 +1324,18 @@ class CLIP_OT_track_settings_to_track(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1136,6 +1366,12 @@ class CLIP_OT_track_settings_to_track(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1190,6 +1426,18 @@ class CLIP_OT_track_settings_to_track(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1225,9 +1473,6 @@ class CLIP_OT_track_to_empty(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -1240,6 +1485,18 @@ class CLIP_OT_track_to_empty(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1270,6 +1527,12 @@ class CLIP_OT_track_to_empty(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1318,6 +1581,24 @@ class CLIP_OT_track_to_empty(bpy_types.Operator):
         '''
         pass
 
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1353,7 +1634,7 @@ def CLIP_default_settings_from_track(clip, track, framenr):
     pass
 
 
-def CLIP_set_viewport_background(context, all_screens, clip, clip_user):
+def CLIP_set_viewport_background(context, clip, clip_user):
     ''' 
 
     '''
