@@ -9,9 +9,6 @@ class ShaderFxButtonsPanel:
     bl_context = None
     ''' '''
 
-    bl_options = None
-    ''' '''
-
     bl_region_type = None
     ''' '''
 
@@ -42,60 +39,6 @@ class DATA_PT_shader_fx(ShaderFxButtonsPanel, bpy_types.Panel,
     id_data = None
     ''' '''
 
-    def FX_BLUR(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_COLORIZE(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_FLIP(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_GLOW(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_PIXEL(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_RIM(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_SHADOW(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_SWIRL(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
-    def FX_WAVE(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
     def append(self, draw_func):
         ''' 
 
