@@ -3,13 +3,15 @@ import typing
 import bpy.types
 
 from . import types
-from . import ops
 from . import utils
-from . import app
-from . import path
-from . import props
-from . import context
+from . import ops
 from . import msgbus
+from . import app
+from . import props
+from . import path
+
+GenericType = typing.TypeVar("GenericType")
+context: 'bpy.types.Context' = None
 
 data: 'bpy.types.BlendData' = None
 ''' Access to Blender's internal data
