@@ -1,24 +1,25 @@
 import sys
 import typing
 from . import icons
-from . import handlers
-from . import timers
 from . import translations
+from . import timers
+from . import handlers
 
+GenericType = typing.TypeVar("GenericType")
 alembic = None
 ''' constant value bpy.app.alembic(supported=True, version=(1, 7, 12), version_string=' 1, 7, 12')
 '''
 
 autoexec_fail = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_message = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_quiet = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 background = None
