@@ -2,16 +2,18 @@ import sys
 import typing
 import bpy.types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def abspath(path,
             start: typing.Union[str, bytes] = None,
-            library: 'bpy.types.Library' = None):
+            library: typing.Optional['bpy.types.Library'] = None):
     ''' Returns the absolute path relative to the current blend file using the "//" prefix.
 
     :param start: Relative to this path, when not set the current filename is used.
     :type start: typing.Union[str, bytes]
     :param library: The library this path is from. This is only included for convenience, when the library is not None its path replaces *start*.
-    :type library: 'bpy.types.Library'
+    :type library: typing.Optional['bpy.types.Library']
     '''
 
     pass
@@ -57,13 +59,15 @@ def display_name_to_filepath(name):
     pass
 
 
-def ensure_ext(filepath, ext: str, case_sensitive: bool = False):
+def ensure_ext(filepath,
+               ext: typing.Optional[str],
+               case_sensitive: typing.Optional[bool] = False):
     ''' Return the path with the extension added if it is not already set.
 
     :param ext: The extension to check for, can be a compound extension. Should start with a dot, such as '.blend' or '.tar.gz'.
-    :type ext: str
+    :type ext: typing.Optional[str]
     :param case_sensitive: Check for matching case when comparing extensions.
-    :type case_sensitive: bool
+    :type case_sensitive: typing.Optional[bool]
     '''
 
     pass
@@ -79,13 +83,15 @@ def is_subdir(path: typing.Union[str, bytes], directory):
     pass
 
 
-def module_names(path: str, recursive: bool = False) -> list:
+def module_names(path: typing.Optional[str],
+                 recursive: typing.Optional[bool] = False) -> typing.List:
     ''' Return a list of modules which can be imported from *path*.
 
     :param path: a directory to scan.
-    :type path: str
+    :type path: typing.Optional[str]
     :param recursive: Also return submodule names for packages.
-    :type recursive: bool
+    :type recursive: typing.Optional[bool]
+    :rtype: typing.List
     :return: a list of string pairs (module_name, module_file).
     '''
 
@@ -93,18 +99,19 @@ def module_names(path: str, recursive: bool = False) -> list:
 
 
 def native_pathsep(path):
-    ''' Replace the path separator with the systems native os.sep .
+    ''' Replace the path separator with the systems native ``os.sep``.
 
     '''
 
     pass
 
 
-def reduce_dirs(dirs: list) -> list:
+def reduce_dirs(dirs: typing.Optional[typing.Sequence]) -> typing.List:
     ''' Given a sequence of directories, remove duplicates and any directories nested in one of the other paths. (Useful for recursive path searching).
 
     :param dirs: Sequence of directory paths.
-    :type dirs: list
+    :type dirs: typing.Optional[typing.Sequence]
+    :rtype: typing.List
     :return: A unique list of paths.
     '''
 
