@@ -22,30 +22,31 @@ class ImagePreviewCollection:
         pass
 
     def load(self,
-             name: str,
-             filepath: str,
-             filetype: str,
-             force_reload: bool = False) -> 'bpy.types.ImagePreview':
-        ''' Generate a new preview from given file path, or return existing one matching name .
+             name: typing.Optional[str],
+             filepath: typing.Optional[str],
+             filetype: typing.Optional[str],
+             force_reload: typing.Optional[bool] = False
+             ) -> 'bpy.types.ImagePreview':
+        ''' Generate a new preview from given file path, or return existing one matching ``name``.
 
         :param name: The name (unique id) identifying the preview.
-        :type name: str
+        :type name: typing.Optional[str]
         :param filepath: The file path to generate the preview from.
-        :type filepath: str
+        :type filepath: typing.Optional[str]
         :param filetype: The type of file, needed to generate the preview in ['IMAGE', 'MOVIE', 'BLEND', 'FONT'].
-        :type filetype: str
+        :type filetype: typing.Optional[str]
         :param force_reload: If True, force running thumbnail manager even if preview already exists in cache.
-        :type force_reload: bool
+        :type force_reload: typing.Optional[bool]
         :rtype: 'bpy.types.ImagePreview'
         :return: The Preview matching given name, or a new empty one.
         '''
         pass
 
-    def new(self, name: str) -> 'bpy.types.ImagePreview':
-        ''' Generate a new empty preview, or return existing one matching name .
+    def new(self, name: typing.Optional[str]) -> 'bpy.types.ImagePreview':
+        ''' Generate a new empty preview, or return existing one matching ``name``.
 
         :param name: The name (unique id) identifying the preview.
-        :type name: str
+        :type name: typing.Optional[str]
         :rtype: 'bpy.types.ImagePreview'
         :return: The Preview matching given name, or a new empty one.
         '''
@@ -62,11 +63,11 @@ def new() -> 'ImagePreviewCollection':
     pass
 
 
-def remove(pcoll: 'ImagePreviewCollection'):
+def remove(pcoll: typing.Optional['ImagePreviewCollection']):
     ''' Remove the specified previews collection.
 
     :param pcoll: Preview collection to close.
-    :type pcoll: 'ImagePreviewCollection'
+    :type pcoll: typing.Optional['ImagePreviewCollection']
     '''
 
     pass
