@@ -1,7 +1,8 @@
 import sys
 import typing
 import bpy.types
-import bpy.context
+
+GenericType = typing.TypeVar("GenericType")
 
 
 class ExportHelper:
@@ -42,7 +43,7 @@ def axis_conversion(from_forward='Y', from_up='Z', to_forward='Y', to_up='Z'):
 
 def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
                            up_attr: str) -> bool:
-    ''' Function to ensure an operator has valid axis conversion settings, intended to be used from bpy.types.Operator.check .
+    ''' Function to ensure an operator has valid axis conversion settings, intended to be used from `bpy.types.Operator.check`.
 
     :param operator: the operator to access axis attributes from.
     :type operator: 'bpy.types.Operator'
@@ -50,6 +51,7 @@ def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
     :type forward_attr: str
     :param up_attr: attribute storing the up axis
     :type up_attr: str
+    :rtype: bool
     :return: True if the value was modified.
     '''
 
@@ -80,13 +82,14 @@ def orientation_helper(axis_forward='Y', axis_up='Z'):
     pass
 
 
-def path_reference(filepath: str,
-                   base_src: str,
-                   base_dst: str,
-                   mode: str = 'AUTO',
-                   copy_subdir: str = '',
-                   copy_set: set = None,
-                   library: 'bpy.types.Library' = None) -> str:
+def path_reference(
+        filepath: str,
+        base_src: str,
+        base_dst: str,
+        mode: str = 'AUTO',
+        copy_subdir: str = '',
+        copy_set: typing.Set = None,
+        library: typing.Optional['bpy.types.Library'] = None) -> str:
     ''' Return a filepath relative to a destination directory, for use with exporters.
 
     :param filepath: the file path to return, supporting blenders relative '//' prefix.
@@ -100,41 +103,45 @@ def path_reference(filepath: str,
     :param copy_subdir: the subdirectory of *base_dst* to use when mode='COPY'.
     :type copy_subdir: str
     :param copy_set: collect from/to pairs when mode='COPY', pass to *path_reference_copy* when exporting is done.
-    :type copy_set: set
+    :type copy_set: typing.Set
     :param library: The library this path is relative to.
-    :type library: 'bpy.types.Library'
+    :type library: typing.Optional['bpy.types.Library']
+    :rtype: str
     :return: the new filepath.
     '''
 
     pass
 
 
-def path_reference_copy(copy_set: set, report='<built-in function print>'):
+def path_reference_copy(copy_set: typing.Set,
+                        report: typing.Any = '<built-in function print>'):
     ''' Execute copying files of path_reference
 
     :param copy_set: set of (from, to) pairs to copy.
-    :type copy_set: set
+    :type copy_set: typing.Set
     :param report: function used for reporting warnings, takes a string argument.
+    :type report: typing.Any
     '''
 
     pass
 
 
-def unique_name(key: 'bpy.context.object',
+def unique_name(key: typing.Any,
                 name: str,
-                name_dict: dict,
+                name_dict: typing.Dict,
                 name_max=-1,
-                clean_func=None,
+                clean_func: typing.Any = None,
                 sep: str = '.'):
     ''' Helper function for storing unique names which may have special characters stripped and restricted to a maximum length.
 
     :param key: unique item this name belongs to, name_dict[key] will be reused when available. This can be the object, mesh, material, etc instance its self.
-    :type key: 'bpy.context.object'
+    :type key: typing.Any
     :param name: The name used to create a unique value in *name_dict*.
     :type name: str
     :param name_dict: This is used to cache namespace to ensure no collisions occur, this should be an empty dict initially and only modified by this function.
-    :type name_dict: dict
+    :type name_dict: typing.Dict
     :param clean_func: Function to call on *name* before creating a unique value.
+    :type clean_func: typing.Any
     :param sep: Separator to use when between the name and a number when a duplicate name is found.
     :type sep: str
     '''
