@@ -4,9 +4,11 @@ import freestyle.types
 import bpy.types
 import mathutils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class BackboneStretcherShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > BackboneStretcherShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BackboneStretcherShader` [Geometry shader]
     '''
 
     def __init__(self, amount: float = 2.0):
@@ -27,7 +29,7 @@ class BackboneStretcherShader:
 
 
 class BezierCurveShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > BezierCurveShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BezierCurveShader` [Geometry shader]
     '''
 
     def __init__(self, error: float = 4.0):
@@ -48,15 +50,15 @@ class BezierCurveShader:
 
 
 class BlenderTextureShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > BlenderTextureShader [Texture shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BlenderTextureShader` [Texture shader]
     '''
 
-    def __init__(self, texture: typing.Union[
-            'bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']):
+    def __init__(self, texture: typing.Union['bpy.types.LineStyleTextureSlot',
+                                             'bpy.types.ShaderNodeTree']):
         ''' Builds a BlenderTextureShader object.
 
         :param texture: A line style texture slot or a shader node tree to define a set of textures.
-        :type texture: typing.Union['bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']
+        :type texture: typing.Union['bpy.types.LineStyleTextureSlot', 'bpy.types.ShaderNodeTree']
         '''
         pass
 
@@ -70,11 +72,13 @@ class BlenderTextureShader:
 
 
 class CalligraphicShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > CalligraphicShader [Thickness Shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `CalligraphicShader` [Thickness Shader]
     '''
 
     def __init__(self, thickness_min: float, thickness_max: float,
-                 orientation: 'mathutils.Vector', clamp: bool):
+                 orientation: typing.
+                 Union[typing.Sequence[float], 'mathutils.Vector'],
+                 clamp: bool):
         ''' Builds a CalligraphicShader object.
 
         :param thickness_min: The minimum thickness in the direction perpendicular to the main direction.
@@ -82,7 +86,7 @@ class CalligraphicShader:
         :param thickness_max: The maximum thickness in the main direction.
         :type thickness_max: float
         :param orientation: The 2D vector giving the main direction.
-        :type orientation: 'mathutils.Vector'
+        :type orientation: typing.Union[typing.Sequence[float], 'mathutils.Vector']
         :param clamp: If true, the strokes are drawn in black when the stroke direction is between -90 and 90 degrees with respect to the main direction and drawn in white otherwise. If false, the strokes are always drawn in black.
         :type clamp: bool
         '''
@@ -98,7 +102,7 @@ class CalligraphicShader:
 
 
 class ColorNoiseShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > ColorNoiseShader [Color shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ColorNoiseShader` [Color shader]
     '''
 
     def __init__(self, amplitude: float, period: float):
@@ -121,7 +125,7 @@ class ColorNoiseShader:
 
 
 class ConstantColorShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > ConstantColorShader [Color shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstantColorShader` [Color shader]
     '''
 
     def __init__(self,
@@ -152,7 +156,7 @@ class ConstantColorShader:
 
 
 class ConstantThicknessShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > ConstantThicknessShader [Thickness shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstantThicknessShader` [Thickness shader]
     '''
 
     def __init__(self, thickness: float):
@@ -173,7 +177,7 @@ class ConstantThicknessShader:
 
 
 class ConstrainedIncreasingThicknessShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > ConstrainedIncreasingThicknessShader [Thickness shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstrainedIncreasingThicknessShader` [Thickness shader]
     '''
 
     def __init__(self, thickness_min: float, thickness_max: float,
@@ -190,7 +194,7 @@ class ConstrainedIncreasingThicknessShader:
         pass
 
     def shade(self, stroke: 'freestyle.types.Stroke'):
-        ''' Same as the IncreasingThicknessShader , but here we allow the user to control the thickness/length ratio so that we don't get fat short lines.
+        ''' Same as the `IncreasingThicknessShader`, but here we allow the user to control the thickness/length ratio so that we don't get fat short lines.
 
         :param stroke: A Stroke object.
         :type stroke: 'freestyle.types.Stroke'
@@ -199,7 +203,7 @@ class ConstrainedIncreasingThicknessShader:
 
 
 class GuidingLinesShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > GuidingLinesShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `GuidingLinesShader` [Geometry shader]
     '''
 
     def __init__(self, offset: float):
@@ -220,7 +224,7 @@ class GuidingLinesShader:
 
 
 class IncreasingColorShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > IncreasingColorShader [Color shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingColorShader` [Color shader]
     '''
 
     def __init__(self, red_min: float, green_min: float, blue_min: float,
@@ -257,7 +261,7 @@ class IncreasingColorShader:
 
 
 class IncreasingThicknessShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > IncreasingThicknessShader [Thickness shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingThicknessShader` [Thickness shader]
     '''
 
     def __init__(self, thickness_A: float, thickness_B: float):
@@ -280,7 +284,7 @@ class IncreasingThicknessShader:
 
 
 class PolygonalizationShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > PolygonalizationShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `PolygonalizationShader` [Geometry shader]
     '''
 
     def __init__(self, error: float):
@@ -315,7 +319,7 @@ class RoundCapShader:
 
 
 class SamplingShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > SamplingShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SamplingShader` [Geometry shader]
     '''
 
     def __init__(self, sampling: float):
@@ -336,7 +340,7 @@ class SamplingShader:
 
 
 class SmoothingShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > SmoothingShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SmoothingShader` [Geometry shader]
     '''
 
     def __init__(self,
@@ -379,7 +383,7 @@ class SmoothingShader:
 
 
 class SpatialNoiseShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > SpatialNoiseShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SpatialNoiseShader` [Geometry shader]
     '''
 
     def __init__(self, amount: float, scale: float, num_octaves: int,
@@ -417,7 +421,7 @@ class SquareCapShader:
 
 
 class StrokeTextureStepShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > StrokeTextureStepShader [Texture shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `StrokeTextureStepShader` [Texture shader]
     '''
 
     def __init__(self, step: float):
@@ -438,7 +442,7 @@ class StrokeTextureStepShader:
 
 
 class ThicknessNoiseShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > ThicknessNoiseShader [Thickness shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ThicknessNoiseShader` [Thickness shader]
     '''
 
     def __init__(self, amplitude: float, period: float):
@@ -461,7 +465,7 @@ class ThicknessNoiseShader:
 
 
 class TipRemoverShader:
-    ''' Class hierarchy: freestyle.types.StrokeShader > TipRemoverShader [Geometry shader]
+    ''' Class hierarchy: `freestyle.types.StrokeShader` > `TipRemoverShader` [Geometry shader]
     '''
 
     def __init__(self, tip_length: float):
