@@ -2,6 +2,8 @@ import sys
 import typing
 import bpy_types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
     bl_idname = None
@@ -22,6 +24,18 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -34,7 +48,7 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -52,6 +66,12 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -112,6 +132,18 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -147,6 +179,18 @@ class BUILTIN_KSI_BendyBones(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -159,7 +203,7 @@ class BUILTIN_KSI_BendyBones(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -177,6 +221,12 @@ class BUILTIN_KSI_BendyBones(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -231,7 +281,19 @@ class BUILTIN_KSI_BendyBones(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, _ksi, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
         ''' 
 
         '''
@@ -272,6 +334,18 @@ class BUILTIN_KSI_DeltaLocation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -302,6 +376,12 @@ class BUILTIN_KSI_DeltaLocation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -356,7 +436,19 @@ class BUILTIN_KSI_DeltaLocation(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, _ksi, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
         ''' 
 
         '''
@@ -397,6 +489,18 @@ class BUILTIN_KSI_DeltaRotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -427,6 +531,12 @@ class BUILTIN_KSI_DeltaRotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -481,7 +591,19 @@ class BUILTIN_KSI_DeltaRotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, _ksi, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
         ''' 
 
         '''
@@ -522,6 +644,18 @@ class BUILTIN_KSI_DeltaScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -552,6 +686,12 @@ class BUILTIN_KSI_DeltaScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -606,7 +746,19 @@ class BUILTIN_KSI_DeltaScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, _ksi, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
         ''' 
 
         '''
@@ -647,6 +799,18 @@ class BUILTIN_KSI_LocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -677,6 +841,12 @@ class BUILTIN_KSI_LocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -737,6 +907,18 @@ class BUILTIN_KSI_LocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -775,6 +957,18 @@ class BUILTIN_KSI_LocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -805,6 +999,12 @@ class BUILTIN_KSI_LocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -865,6 +1065,18 @@ class BUILTIN_KSI_LocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -900,6 +1112,18 @@ class BUILTIN_KSI_LocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -930,6 +1154,12 @@ class BUILTIN_KSI_LocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -990,6 +1220,18 @@ class BUILTIN_KSI_LocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1028,6 +1270,18 @@ class BUILTIN_KSI_Location(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1040,7 +1294,7 @@ class BUILTIN_KSI_Location(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -1058,6 +1312,12 @@ class BUILTIN_KSI_Location(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1118,6 +1378,18 @@ class BUILTIN_KSI_Location(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1153,6 +1425,18 @@ class BUILTIN_KSI_RotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1183,6 +1467,12 @@ class BUILTIN_KSI_RotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1243,6 +1533,18 @@ class BUILTIN_KSI_RotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1281,6 +1583,18 @@ class BUILTIN_KSI_Rotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1293,7 +1607,7 @@ class BUILTIN_KSI_Rotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -1311,6 +1625,12 @@ class BUILTIN_KSI_Rotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1371,6 +1691,18 @@ class BUILTIN_KSI_Rotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1409,6 +1741,18 @@ class BUILTIN_KSI_Scaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1421,7 +1765,7 @@ class BUILTIN_KSI_Scaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -1439,6 +1783,12 @@ class BUILTIN_KSI_Scaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1499,6 +1849,18 @@ class BUILTIN_KSI_Scaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1537,6 +1899,18 @@ class BUILTIN_KSI_VisualLoc(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1549,7 +1923,7 @@ class BUILTIN_KSI_VisualLoc(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -1567,6 +1941,12 @@ class BUILTIN_KSI_VisualLoc(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1627,6 +2007,18 @@ class BUILTIN_KSI_VisualLoc(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1665,6 +2057,18 @@ class BUILTIN_KSI_VisualLocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1695,6 +2099,12 @@ class BUILTIN_KSI_VisualLocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1755,6 +2165,18 @@ class BUILTIN_KSI_VisualLocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1793,6 +2215,18 @@ class BUILTIN_KSI_VisualLocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1823,6 +2257,12 @@ class BUILTIN_KSI_VisualLocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1883,6 +2323,18 @@ class BUILTIN_KSI_VisualLocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1921,6 +2373,18 @@ class BUILTIN_KSI_VisualLocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1951,6 +2415,12 @@ class BUILTIN_KSI_VisualLocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2011,6 +2481,18 @@ class BUILTIN_KSI_VisualLocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2049,6 +2531,18 @@ class BUILTIN_KSI_VisualRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2061,7 +2555,7 @@ class BUILTIN_KSI_VisualRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -2079,6 +2573,12 @@ class BUILTIN_KSI_VisualRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2139,6 +2639,18 @@ class BUILTIN_KSI_VisualRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2177,6 +2689,18 @@ class BUILTIN_KSI_VisualRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2207,6 +2731,12 @@ class BUILTIN_KSI_VisualRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2267,6 +2797,18 @@ class BUILTIN_KSI_VisualRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2305,6 +2847,18 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2317,7 +2871,7 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _ksi, _context, ks, data):
         ''' 
 
         '''
@@ -2335,6 +2889,12 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2395,6 +2955,18 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2442,6 +3014,18 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def doBBone(self, ksi, context, ks, pchan):
         ''' 
 
@@ -2508,6 +3092,12 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2568,6 +3158,18 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2612,6 +3214,18 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def doBBone(self, ksi, context, ks, pchan):
         ''' 
 
@@ -2678,6 +3292,12 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2738,6 +3358,18 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
